@@ -27,6 +27,22 @@ def view_df(df: pandas.DataFrame, head_num: int = 5, tail_num: int = 5, comment:
     return df.head(head_num).append(df.tail(tail_num))
 
 
+def pandas_set(max_row: int = 0, max_col: int = 0, max_col_w: int = 0, max_char_size: int = 0,
+               float_precision: int = 0):
+    """
+    @param max_row: 显示最大行数
+    @param max_col: 显示最大列数
+    @max_col_w: 显示列长度
+    @max_char_size: 显示横向最多字符数
+    @float_precision: 显示浮点数最多位数
+    """
+    max_row and pandas.set_option('display.max_rows', max_row)
+    max_col and pandas.set_option('display.max_columns', max_col)
+    max_col_w and pandas.set_option('display.max_colwidth', max_col_w)
+    max_char_size and pandas.set_option('display.width', max_char_size)
+    float_precision and pandas.set_option('precision', float_precision)
+
+
 import warnings
 
 
