@@ -77,6 +77,14 @@ def is_number(s):
     return False
 
 
+def escape(value: str):
+    """转义特殊字符"""
+    reserved_chars = r'''?&|!{}[]()^~*:\\"'+- /'''
+    replace = ['\\' + l for l in reserved_chars]
+    trans = str.maketrans(dict(zip(reserved_chars, replace)))
+    return value.translate(trans)
+
+
 if __name__ == '__main__':
     print(split('a;b;;c', ';', '_', '.bin'))
     print(split(['a', 'b', 'c'], ';', '_', '.bin'))
